.. oda_api documentation master file, created by
   sphinx-quickstart on Sun Mar 10 18:29:05 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ODA API documentation
===================================
API for cdci_data_analysis

:Author: `Andrea Tramacere <andrea.tramacere@unige.ch>`_

Documentation
-------------

.. toctree::
   :maxdepth: 1

   installation <install.rst>
   tutorial  <user_guide/tutorial_main.rst>
   code documentation (API) <api/modules.rst>
.. user guide <user_guide/user_guide.rst>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
